@@ -30,9 +30,19 @@ class AkamaiV2Cracker(BaseCracker):
     must_check_params = ["href"]
     # 默认可选参数
     option_params = {
+        "branch": "Master",
         "api": "",
         "telemetry": False,
-        "uncheck": True,
-        "http2": True,
-        "device": "mobile"
+        "uncheck": False,
+        "sec_cpt_script": None,
+        "sec_cpt_duration": None,
+        "sec_cpt_src": None,
+        "sec_cpt_html": None,
+        "sec_cpt_challenge": {},
+        "proxy": None,
+        "cookies": {},
+        "country": None,
+        "ip": None,
+        "user_agent": None,
+        "timeout": 30
     }
\ No newline at end of file
