@@ -1,7 +1,8 @@
 
+from typing import Any
+
 import requests
 from loguru import logger
-from typing import Any
 
 
 class BaseCracker:
@@ -24,20 +25,20 @@ class BaseCracker:
     _extra_data = None
     
     def __init__(
-        self,    
+        self,   
+        show_ad=True, 
         user_token: str = None,
         developer_id: str = None,   
-        user_agent: str = None,
-        cookies: dict = {},
-        proxy: str = None, 
-        timeout: int = 30,
-        debug: bool = False,
-        check_useful: bool = False,
-        max_retry_times: int = 3,
-        internal=True,
-        internal_api=True,
-        auth=False,
-        show_ad=True,
+        internal_host: bool = False,
+        # user_agent: str = None,
+        # cookies: dict = {},
+        # proxy: str = None, 
+        # timeout: int = 30,
+        # debug: bool = False,
+        # check_useful: bool = False,
+        # max_retry_times: int = 3,
+        # internal=True,
+        # auth=False,
         **kwargs
     ) -> None:
         """
@@ -51,6 +52,7 @@ class BaseCracker:
         :param max_retry_times: 最大重试次数
         :param internal: 是否使用国内代理
         :param auth: 是否大户通道验证模式
+        :param internal_host: 是否使用国内域名 api.nocaptcha.cn, 默认 api.nocaptcha.io
         """
         if show_ad:
             logger.debug("感谢选择 nocaptcha, 我们只做别人做不到的(手动狗头)~")
@@ -59,18 +61,18 @@ class BaseCracker:
         if not self.user_token:
             raise Exception("缺少用户凭证")
         self.developer_id = developer_id
-        self.cookies = cookies
-        self.user_agent = user_agent
-        self.proxy = proxy
-        self.timeout = timeout
-        self.debug = debug
-        self.check_useful = check_useful
-        self.max_retry_times = max_retry_times
-
-        self.internal_api = internal_api
+        self.cookies = kwargs.get("cookies") or {}
+        self.user_agent = kwargs.get("user_agent")
+        self.proxy = kwargs.get("proxy")
+        self.timeout = kwargs.get("timeout") or 30
+        self.debug = kwargs.get("debug", False)
+        self.check_useful = kwargs.get("check_useful", False)
+        self.max_retry_times = kwargs.get("max_retry_times", 3)
+        self.api_host = 'api.nocaptcha.cn' if internal_host else 'api.nocaptcha.io'
         self.wanda_args = {
-            "internal": internal,
-            "auth": auth
+            "internal": kwargs.get('internal', True),
+            "is_auth": kwargs.get('auth', False),
+            "timeout": self.timeout
         }
         for k in self.must_check_params:
             _v = kwargs.get(k)
@@ -89,9 +91,22 @@ class BaseCracker:
             if k in self.wanda_args:
                 del self.wanda_args[k]
 
-        if any(getattr(self, k) is None for k in self.must_check_params):
-           raise AttributeError("缺少参数, 请检查")
+        for k in self.must_check_params:
+            if getattr(self, k) is None:
+                raise AttributeError(f"缺少参数 {k}, 请检查")
 
+        if self.user_agent:
+            self.wanda_args["user_agent"] = self.user_agent
+        if self.cookies:
+            self.wanda_args["cookies"] = self.cookies
+        if self.proxy:
+            self.wanda_args["proxy"] = self.proxy
+
+        self.request()
+        
+    def request(self):
+        pass
+    
     def response(self, result: Any):
         return result
         
@@ -101,6 +116,24 @@ class BaseCracker:
     def extra(self):
         return self._extra_data
     
+    def fix_headers(self, headers: dict):
+        for k, _ in headers.items():
+            k = k.lower()
+            if k in [
+                "sec-ch-ua", 
+                "accept-language",
+                'sec-ch-ua-arch',
+                'sec-ch-ua-bitness',
+                'sec-ch-ua-full-version',
+                'sec-ch-ua-full-version-list',
+                'sec-ch-ua-mobile',
+                'sec-ch-ua-model',
+                'sec-ch-ua-platform',
+                'sec-ch-ua-platform-version',
+                "user-agent",
+            ] and self._extra_data.get(k):
+                headers[k] = self._extra_data[k]            
+    
     def crack(self):
         headers = {
             "User-Token": self.user_token
@@ -108,19 +141,12 @@ class BaseCracker:
         if self.developer_id:
             headers["Developer-Id"] = self.developer_id
         
-        if self.user_agent:
-            self.wanda_args["user_agent"] = self.user_agent
-        if self.cookies:
-            self.wanda_args["cookies"] = self.cookies
-        if self.proxy:
-            self.wanda_args["proxy"] = self.proxy
-
         retry_times = 0        
         resp = {}
         while retry_times < self.max_retry_times:
             try:
                 resp = requests.post(
-                    f"http://{'xn--fjqs46frol.com' if self.internal_api else 'api.nocaptcha.io' }/api/wanda/{self.cracker_name}/{self.cracker_version}", 
+                    f"http://{self.api_host}/api/wanda/{self.cracker_name}/{self.cracker_version}", 
                     headers=headers, json=self.wanda_args, timeout=self.timeout
                 ).json()
                 if self.debug:
