@@ -1,6 +1,7 @@
+import warnings
+
 from .base import BaseCracker
 
-import warnings
 warnings.filterwarnings('ignore')
 
 
@@ -16,7 +17,7 @@ class CloudFlareCracker(BaseCracker):
     :param headers: 触发验证必须的 headers, 默认 {} 
     :param cookies: 触发验证必须的 cookies, 默认 {} 
     :param html: 是否需要返回 html
-    :param turnstile: 是否需要 cf_turnstile-response 参数
+    :param alpha: 是否 alpha 模式, true 会更快
     :param timeout: 最大破解超时时间
     调用示例:
     cracker = CloudFlareCracker(
@@ -27,14 +28,17 @@ class CloudFlareCracker(BaseCracker):
     """
     
     # 必传参数
-    must_check_params = ["href"]
+    must_check_params = ["href", "proxy"]
     # 默认可选参数
     option_params = {
+        "branch": "Master",
         "user_agent": None,
         "headers": {},
         "cookies": {},
-        "proxy": None,
         "html": False,
         "sitekey": "",
+        "alpha": False,
+        "action": None,
+        "cdata": None,
         "timeout": 30
     }
