@@ -34,7 +34,7 @@ class HcaptchaCracker(BaseCracker):
     option_params = {
         "mode": "picture",   # 验证模式, 默认图片验证, 可选 question 题库验证
         "rqdata": "",
+        "region": None,
         "domain": "hcaptcha.com",
-        "device": "chrome",
     }
 
